@@ -1,4 +1,5 @@
 #include "depends.h"
+#ifdef HAVE_GSL_HEADER
 
 /* Function prototype - read in phenotypes for logistic regression */
 gsl_vector_int * readLogisticPhenotypes(char * phenotypefilename,
@@ -10,3 +11,5 @@ int returnToOriginalScaleLogistic(GSL_TYPE(vector) * betaOut,
 				  GSL_TYPE(vector) * means,
 				  GSL_TYPE(vector) * scales,
 				  int intercept_flag);
+#endif
+
